Basic Data Structures
:::::::::::::::::::::

.. toctree::
    :caption: Basic Data Structures
    :maxdepth: 2

    Objectives.rst
    WhatAreLinearStructures.rst
    WhatisaStack.rst
    TheStackAbstractDataType.rst
    ImplementingaStackinPython.rst
    SimpleBalancedParentheses.rst
    BalancedSymbolsAGeneralCase.rst
    ConvertingDecimalNumberstoBinaryNumbers.rst
    InfixPrefixandPostfixExpressions.rst
    WhatIsaQueue.rst
    TheQueueAbstractDataType.rst
    ImplementingaQueueinPython.rst
    SimulationHotPotato.rst
    SimulationPrintingTasks.rst
    WhatIsaDeque.rst
    TheDequeAbstractDataType.rst
    ImplementingaDequeinPython.rst
    PalindromeChecker.rst
    Lists.rst
    TheUnorderedListAbstractDataType.rst
    ImplementinganUnorderedListLinkedLists.rst
    TheOrderedListAbstractDataType.rst
    ImplementinganOrderedList.rst
    Summary.rst
    KeyTerms.rst
    Exercises.rst
